==> applet-spring-3.1.4-sources.jar: cn/sinozg/applet/common/properties/AppValue.java <==
/*
 * Copyright (C) 2020-2024, Xie YuBin
 * The GNU Free Documentation License covers this file. The original version
 * of this license can be found at http://www.gnu.org/licenses/gfdl.html.
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Free Documentation License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Free Documentation License for more details.
 *
 * You should have received a copy of the GNU Free Documentation License
 * along with this program.  If not, see <https://www.gnu.org/licenses/>.
 */

package cn.sinozg.applet.common.properties;

import cn.sinozg.applet.common.constant.BaseConstants;
import org.springframework.boot.context.properties.ConfigurationProperties;
import org.springframework.stereotype.Component;

/**
 * 自定义项目配置
 * @Author: xyb
 * @Description:
 * @Date: 2022-11-14 下午 09:42
 **/
@Component
@ConfigurationProperties(prefix = BaseConstants.APP_PREFIX)
public class AppValue {

    /** 项目版本号 */
    private String version;
    /** 项目名称 */
    private String description;
    /** 前端显示图片的前缀 */
    private String fontUrl;

    /** 登录设置 */
    private LoginValue login;

    /** 微信设置 */
    private WechatValue wechat;

    /** 拦截器 **/
    private ApiUrlValue apiUrl;

    /** 租户 */
    private TenantValue tenant;

    /** 参数签名 */
    private SignValue sign;
    /** 证书地址 */
    private CrtValue crt;

    /**
     * 获取 项目版本号
     *
     * @return version 项目版本号
     */
    public String getVersion() {
        return this.version;
    }

    /**
     * 设置 项目版本号
     *
     * @param version 项目版本号
     */
    public void setVersion(String version) {
        this.version = version;
    }

    /**
     * 获取 项目名称
     *
     * @return description 项目名称
     */
    public String getDescription() {
        return this.description;
    }

    /**
     * 设置 项目名称
     *
     * @param description 项目名称
     */
    public void setDescription(String description) {
        this.description = description;
    }

    /**
     * 获取 前端显示图片的前缀
     *
     * @return fontUrl 前端显示图片的前缀
     */
    public String getFontUrl() {
        return this.fontUrl;
    }

    /**
     * 设置 前端显示图片的前缀
     *
     * @param fontUrl 前端显示图片的前缀
     */
    public void setFontUrl(String fontUrl) {
        this.fontUrl = fontUrl;
    }

    /**
     * 获取 登录设置
     *
     * @return login 登录设置
     */
    public LoginValue getLogin() {
        return this.login;
    }

    /**
     * 设置 登录设置
     *
     * @param login 登录设置
     */
    public void setLogin(LoginValue login) {
        this.login = login;
    }

    /**
     * 获取 微信设置
     *
     * @return wechat 微信设置
     */
    public WechatValue getWechat() {
        return this.wechat;
    }

    /**
     * 设置 微信设置
     *
     * @param wechat 微信设置
     */
    public void setWechat(WechatValue wechat) {
        this.wechat = wechat;
    }

    /**
     * 获取 拦截器
     *
     * @return apiUrl 拦截器
     */
    public ApiUrlValue getApiUrl() {
        return this.apiUrl;
    }

    /**
     * 设置 拦截器
     *
     * @param apiUrl 拦截器
     */
    public void setApiUrl(ApiUrlValue apiUrl) {
        this.apiUrl = apiUrl;
    }

    /**
     * 获取 租户
     *
     * @return tenant 租户
     */
    public TenantValue getTenant() {
        return this.tenant;
    }

    /**
     * 设置 租户
     *
     * @param tenant 租户
     */
    public void setTenant(TenantValue tenant) {
        this.tenant = tenant;
    }

    /**
     * 获取 参数签名
     *
     * @return sign 参数签名
     */
    public SignValue getSign() {
        return this.sign;
    }

    /**
     * 设置 参数签名
     *
     * @param sign 参数签名
     */
    public void setSign(SignValue sign) {
        this.sign = sign;
    }


    /**
     * 获取 证书地址
     *
     * @return crt 证书地址
     */
    public CrtValue getCrt() {
        return this.crt;
    }

    /**
     * 设置 证书地址
     *
     * @param crt 证书地址
     */
    public void setCrt(CrtValue crt) {
        this.crt = crt;
    }
}

==> applet-spring-3.2.1-sources.jar: cn/sinozg/applet/common/properties/AppValue.java <==
/*
 * Copyright (C) 2020-2024, Xie YuBin
 * The GNU Free Documentation License covers this file. The original version
 * of this license can be found at http://www.gnu.org/licenses/gfdl.html.
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Free Documentation License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Free Documentation License for more details.
 *
 * You should have received a copy of the GNU Free Documentation License
 * along with this program.  If not, see <https://www.gnu.org/licenses/>.
 */

package cn.sinozg.applet.common.properties;

import cn.sinozg.applet.common.constant.BaseConstants;
import org.springframework.boot.context.properties.ConfigurationProperties;
import org.springframework.stereotype.Component;

/**
 * 自定义项目配置
 * @Author: xyb
 * @Description:
 * @Date: 2022-11-14 下午 09:42
 **/
@Component
@ConfigurationProperties(prefix = BaseConstants.APP_PREFIX)
public class AppValue {

    /** 项目版本号 */
    private String version;
    /** 项目名称 */
    private String description;
    /** 前端显示图片的前缀 */
    private String fontUrl;

    /** debug 模式 */
    private Boolean debug;

    /** 登录设置 */
    private LoginValue login;

    /** 微信设置 */
    private WechatValue wechat;

    /** 拦截器 **/
    private ApiUrlValue apiUrl;

    /** 租户 */
    private TenantValue tenant;

    /** 参数签名 */
    private SignValue sign;
    /** 证书地址 */
    private CrtValue crt;

    /**
     * 获取 项目版本号
     *
     * @return version 项目版本号
     */
    public String getVersion() {
        return this.version;
    }

    /**
     * 设置 项目版本号
     *
     * @param version 项目版本号
     */
    public void setVersion(String version) {
        this.version = version;
    }

    /**
     * 获取 项目名称
     *
     * @return description 项目名称
     */
    public String getDescription() {
        return this.description;
    }

    /**
     * 设置 项目名称
     *
     * @param description 项目名称
     */
    public void setDescription(String description) {
        this.description = description;
    }

    /**
     * 获取 前端显示图片的前缀
     *
     * @return fontUrl 前端显示图片的前缀
     */
    public String getFontUrl() {
        return this.fontUrl;
    }

    /**
     * 设置 前端显示图片的前缀
     *
     * @param fontUrl 前端显示图片的前缀
     */
    public void setFontUrl(String fontUrl) {
        this.fontUrl = fontUrl;
    }

    /**
     * 获取 debug 模式
     *
     * @return debug 模式
     */
    public Boolean getDebug() {
        return debug;
    }

    /**
     * 设置 debug 模式
     *
     * @param debug debug 模式
     */
    public void setDebug(Boolean debug) {
        this.debug = debug;
    }

    /**
     * 获取 登录设置
     *
     * @return login 登录设置
     */
    public LoginValue getLogin() {
        return this.login;
    }

    /**
     * 设置 登录设置
     *
     * @param login 登录设置
     */
    public void setLogin(LoginValue login) {
        this.login = login;
    }

    /**
     * 获取 微信设置
     *
     * @return wechat 微信设置
     */
    public WechatValue getWechat() {
        return this.wechat;
    }

    /**
     * 设置 微信设置
     *
     * @param wechat 微信设置
     */
    public void setWechat(WechatValue wechat) {
        this.wechat = wechat;
    }

    /**
     * 获取 拦截器
     *
     * @return apiUrl 拦截器
     */
    public ApiUrlValue getApiUrl() {
        return this.apiUrl;
    }

    /**
     * 设置 拦截器
     *
     * @param apiUrl 拦截器
     */
    public void setApiUrl(ApiUrlValue apiUrl) {
        this.apiUrl = apiUrl;
    }

    /**
     * 获取 租户
     *
     * @return tenant 租户
     */
    public TenantValue getTenant() {
        return this.tenant;
    }

    /**
     * 设置 租户
     *
     * @param tenant 租户
     */
    public void setTenant(TenantValue tenant) {
        this.tenant = tenant;
    }

    /**
     * 获取 参数签名
     *
     * @return sign 参数签名
     */
    public SignValue getSign() {
        return this.sign;
    }

    /**
     * 设置 参数签名
     *
     * @param sign 参数签名
     */
    public void setSign(SignValue sign) {
        this.sign = sign;
    }


    /**
     * 获取 证书地址
     *
     * @return crt 证书地址
     */
    public CrtValue getCrt() {
        return this.crt;
    }

    /**
     * 设置 证书地址
     *
     * @param crt 证书地址
     */
    public void setCrt(CrtValue crt) {
        this.crt = crt;
    }
}
